"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findComponentHooks = void 0;
const markPath_1 = require("./markPath");
const markUnsupported_1 = require("./markUnsupported");
const findCallExpressionsInComponents_1 = require("./findCallExpressionsInComponents");
const findRootDeclaration_1 = require("./findRootDeclaration");
function findComponentHooks(rootNode, name, isDev) {
    const result = (0, findCallExpressionsInComponents_1.findCallExpressionsInComponents)(rootNode, name, true);
    for (const item of result.exprs) {
        const { parent, parentName } = (0, findRootDeclaration_1.findRootDeclaration)(item);
        if (parentName == null) {
            const msg = isDev
                ? `[GraphQL Compiler Plugin] ${name} is only supported in named functions.`
                : `Unexpected ${name} call (unnamed parent)`;
            (0, markUnsupported_1.markWithError)(item, msg);
        }
        (0, markPath_1.markPath)(item, name + " in " + parentName);
    }
    for (const item of result.nestedExprs) {
        (0, markPath_1.markPath)(item, "unsupported/nested " + name);
    }
    for (const item of result.allExprs) {
        (0, markPath_1.markPath)(item, "unsupported/unknown " + name);
    }
    const unsupported = new Set([...result.allExprs, ...result.nestedExprs]);
    for (const item of unsupported) {
        (0, markUnsupported_1.markUnsupported)(item, name, isDev);
    }
    return {
        supported: result.exprs,
        unsupported,
    };
}
exports.findComponentHooks = findComponentHooks;
//# sourceMappingURL=findComponentHooks.js.map