"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findRootOfCallExpression = void 0;
const findRootParentOfType_1 = require("./findRootParentOfType");
const markUnsupported_1 = require("./markUnsupported");
const findRootDeclaration_1 = require("./findRootDeclaration");
const names_1 = require("../names");
function findRootOfCallExpression(path, name, isDev, rootNodesFound) {
    var _a, _b, _c;
    const rootExpression = (0, findRootDeclaration_1.findRootDeclaration)(path);
    if (rootExpression.parent == null) {
        const msg = isDev
            ? `[GraphQL Compiler Plugin] ${name} was used in an unsupported location. Please report this error with source code to the developer of the plugin.`
            : `Unexpected ${name} call (unknown context)`;
        (0, markUnsupported_1.markWithError)(path, msg);
        return;
    }
    const moduleRootExpression = (_c = (_b = (_a = (0, findRootParentOfType_1.findRootParentOfType)(rootExpression.parent, "FunctionDeclaration")) !== null && _a !== void 0 ? _a : (0, findRootParentOfType_1.findRootParentOfType)(rootExpression.parent, "ExportNamedDeclaration")) !== null && _b !== void 0 ? _b : (0, findRootParentOfType_1.findRootParentOfType)(rootExpression.parent, "VariableDeclaration")) !== null && _c !== void 0 ? _c : (rootExpression.parent != null &&
        (rootExpression.parent.type === "FunctionDeclaration" ||
            rootExpression.parent.type === "ExportNamedDeclaration" ||
            rootExpression.parent.type === "VariableDeclaration")
        ? rootExpression.parent
        : null);
    if (moduleRootExpression == null) {
        const msg = isDev
            ? `[GraphQL Compiler Plugin] ${name} can only be used in valid module-level declarations.`
            : `Unexpected ${name} call (unknown parent declaration)`;
        (0, markUnsupported_1.markWithError)(path, msg);
        return null;
    }
    if (rootNodesFound.has(moduleRootExpression)) {
        const msg = isDev
            ? `[GraphQL Compiler Plugin] ${name} cannot be used with other occurences of either ${names_1.names.useFragment} or ${names_1.names.useQuery} in a single component.`
            : `Invalid ${name} call (multiple calls in single component)`;
        (0, markUnsupported_1.markWithError)(path, msg);
        return null;
    }
    rootNodesFound.add(moduleRootExpression);
    return moduleRootExpression;
}
exports.findRootOfCallExpression = findRootOfCallExpression;
//# sourceMappingURL=findRootOfCallExpression.js.map