import { markPath } from "./markPath";
import { markUnsupported, markWithError } from "./markUnsupported";
import { findCallExpressionsInComponents } from "./findCallExpressionsInComponents";
import { findRootDeclaration } from "./findRootDeclaration";
export function findComponentHooks(rootNode, name, isDev) {
    const result = findCallExpressionsInComponents(rootNode, name, true);
    for (const item of result.exprs) {
        const { parent, parentName } = findRootDeclaration(item);
        if (parentName == null) {
            const msg = isDev
                ? `[GraphQL Compiler Plugin] ${name} is only supported in named functions.`
                : `Unexpected ${name} call (unnamed parent)`;
            markWithError(item, msg);
        }
        markPath(item, name + " in " + parentName);
    }
    for (const item of result.nestedExprs) {
        markPath(item, "unsupported/nested " + name);
    }
    for (const item of result.allExprs) {
        markPath(item, "unsupported/unknown " + name);
    }
    const unsupported = new Set([...result.allExprs, ...result.nestedExprs]);
    for (const item of unsupported) {
        markUnsupported(item, name, isDev);
    }
    return {
        supported: result.exprs,
        unsupported,
    };
}
//# sourceMappingURL=findComponentHooks.js.map