import { findRootParentOfType } from "./findRootParentOfType";
import { markWithError } from "./markUnsupported";
import { findRootDeclaration } from "./findRootDeclaration";
import { names } from "../names";
export function findRootOfCallExpression(path, name, isDev, rootNodesFound) {
    var _a, _b, _c;
    const rootExpression = findRootDeclaration(path);
    if (rootExpression.parent == null) {
        const msg = isDev
            ? `[GraphQL Compiler Plugin] ${name} was used in an unsupported location. Please report this error with source code to the developer of the plugin.`
            : `Unexpected ${name} call (unknown context)`;
        markWithError(path, msg);
        return;
    }
    const moduleRootExpression = (_c = (_b = (_a = findRootParentOfType(rootExpression.parent, "FunctionDeclaration")) !== null && _a !== void 0 ? _a : findRootParentOfType(rootExpression.parent, "ExportNamedDeclaration")) !== null && _b !== void 0 ? _b : findRootParentOfType(rootExpression.parent, "VariableDeclaration")) !== null && _c !== void 0 ? _c : (rootExpression.parent != null &&
        (rootExpression.parent.type === "FunctionDeclaration" ||
            rootExpression.parent.type === "ExportNamedDeclaration" ||
            rootExpression.parent.type === "VariableDeclaration")
        ? rootExpression.parent
        : null);
    if (moduleRootExpression == null) {
        const msg = isDev
            ? `[GraphQL Compiler Plugin] ${name} can only be used in valid module-level declarations.`
            : `Unexpected ${name} call (unknown parent declaration)`;
        markWithError(path, msg);
        return null;
    }
    if (rootNodesFound.has(moduleRootExpression)) {
        const msg = isDev
            ? `[GraphQL Compiler Plugin] ${name} cannot be used with other occurences of either ${names.useFragment} or ${names.useQuery} in a single component.`
            : `Invalid ${name} call (multiple calls in single component)`;
        markWithError(path, msg);
        return null;
    }
    rootNodesFound.add(moduleRootExpression);
    return moduleRootExpression;
}
//# sourceMappingURL=findRootOfCallExpression.js.map