import { types } from "@babel/core";
import { names } from "../names";
export function transformGraphQL(parentName, callPath, argument, isFragment) {
    if (!types.isTemplateLiteral(argument)) {
        throw new Error("Only template literals are allowed");
    }
    let quasis = [];
    let expressions = [];
    const refs = [];
    const foundRefs = new Set();
    let i = 0;
    for (const expr of argument.expressions) {
        quasis.push(argument.quasis[i++]);
        if (!types.isIdentifier(expr)) {
            expressions.push(types.nullLiteral());
            continue;
        }
        const binding = callPath.scope.getBinding(expr.name);
        if (binding == null) {
            expressions.push(types.nullLiteral());
            continue;
        }
        const nameIdentifier = types.memberExpression(types.identifier(expr.name), types.identifier(names.literName));
        const nameCallExpr = types.callExpression(nameIdentifier, []);
        expressions.push(nameCallExpr);
        const sourceIdentifier = types.memberExpression(types.identifier(expr.name), types.identifier(names.literInternalName));
        if (!foundRefs.has(expr.name)) {
            foundRefs.add(expr.name);
            refs.push(sourceIdentifier);
        }
    }
    quasis.push(argument.quasis[i]);
    quasis = quasis.map((el, i) => {
        el.value.raw = compressGraphQL(el.value.raw);
        // The check for ... at the end makes sure that we can have ... inside fragments to support type "importing".
        // These dots SHOULD have no effects on the compiled output, but is a hint for the codegen module.
        if (i < quasis.length - 1 && !el.value.raw.endsWith("...")) {
            el.value.raw += " ...";
        }
        if (i > 0) {
            el.value.raw = " " + el.value.raw;
        }
        return el;
    });
    /*if (refs.length > 0) {
      quasis[quasis.length - 1].value.raw =
        quasis[quasis.length - 1].value.raw + " ";
  
      for (const el of refs) {
        quasis.push(types.templateElement({ raw: " " }));
        expressions.push(el);
      }
      quasis[quasis.length - 1].value.raw = quasis[
        quasis.length - 1
      ].value.raw.trimRight();
    }*/
    if (isFragment) {
        quasis[0].value.raw = " " + quasis[0].value.raw.trimLeft();
        quasis.unshift(types.templateElement({
            raw: "fragment ",
        }));
        expressions.unshift(types.callExpression(types.memberExpression(types.identifier(parentName), types.identifier(names.literName)), []));
    }
    quasis = quasis.map((el, i) => {
        el.value.cooked = el.value.raw;
        return el;
    });
    return {
        ast: types.templateLiteral(quasis, expressions),
        referenced: refs,
    };
}
function compressGraphQL(s) {
    return s.replace(/(?:\s|\n)+/g, " ").trim();
}
//# sourceMappingURL=transformGraphql.js.map